@@ -5,16 +5,16 @@
 # This file is part of weboob.
 #
 # weboob is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as published by
+# it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
 # weboob is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
+# GNU Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Affero General Public License
+# You should have received a copy of the GNU Lesser General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 from __future__ import absolute_import
@@ -328,6 +328,9 @@ class Form(OrderedDict):
     def submit(self, **kwargs):
         """
         Submit the form and tell browser to be located to the new page.
+
+        :param data_encoding: force encoding used to submit form data (defaults to the current page encoding)
+        :type data_encoding: :class:`basestring`
         """
         kwargs.setdefault('data_encoding', self.page.encoding)
         return self.page.browser.location(self.request, **kwargs)
