@@ -5,16 +5,16 @@
 # This file is part of weboob.
 #
 # weboob is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as published by
+# it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
 # weboob is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
+# GNU Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Affero General Public License
+# You should have received a copy of the GNU Lesser General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 
@@ -47,6 +47,12 @@ class WebNip(object):
     It provides methods to build backends or call methods on all loaded
     backends.
 
+    You should use this class when you want to build an application
+    using Weboob as a library, without using the standard modules nor
+    the automatic module download and update machanism. When using
+    WebNip, you have to explicitely provide module paths and deal
+    yourself with backend configuration.
+
     :param modules_path: path to directory containing modules.
     :type modules_path: :class:`basestring`
     :param storage: provide a storage where backends can save data
@@ -54,7 +60,7 @@ class WebNip(object):
     :param scheduler: what scheduler to use; default is :class:`weboob.core.scheduler.Scheduler`
     :type scheduler: :class:`weboob.core.scheduler.IScheduler`
     """
-    VERSION = '1.4'
+    VERSION = '1.5'
 
     def __init__(self, modules_path=None, storage=None, scheduler=None):
         self.logger = getLogger('weboob')
@@ -89,7 +95,7 @@ class WebNip(object):
         """
         self.unload_backends()
 
-    def build_backend(self, module_name, params=None, storage=None, name=None, nofail=False):
+    def build_backend(self, module_name, params=None, storage=None, name=None, nofail=False, logger=None):
         """
         Create a backend.
 
@@ -109,7 +115,7 @@ class WebNip(object):
         """
         module = self.modules_loader.get_or_load_module(module_name)
 
-        backend_instance = module.create_instance(self, name or module_name, params or {}, storage, nofail)
+        backend_instance = module.create_instance(self, name or module_name, params or {}, storage, nofail, logger=logger or self.logger)
         return backend_instance
 
     class LoadError(Exception):
